@@ -6,7 +6,7 @@ library(dplyr, warn.conflicts=F)  # for data_frame
 source("utils.R")
 
 test_that("reading & writing UUID columns", {
-  writeReadTest(as.data.frame(data_frame(a=as.character(c(
+  writeReadTest(as.data.frame(tibble(a=as.character(c(
       "049b9423-38e3-4722-a9f6-b98c0dc87190",
       "67de9c22-bb18-4d4d-b47f-8cf795ab4709",
       "b59c08f5-4a20-4f0e-8e32-a48a61732635",
@@ -15,7 +15,7 @@ test_that("reading & writing UUID columns", {
 })
 
 test_that("reading & writing Nullable UUID columns", {
-  writeReadTest(as.data.frame(data_frame(b=as.character(c(
+  writeReadTest(as.data.frame(tibble(b=as.character(c(
       "049b9423-38e3-4722-a9f6-b98c0dc87190",
       NA,
       "b59c08f5-4a20-4f0e-8e32-a48a61732635",
